# package_template
A Template to build a PIP package
## Authors- [@chankyswami]
(https://www.github.com/chankyswami)
## InstallationInstall my-project with pip```bash
  pip install package_template
```## Requirements* 
numpy